@@ -17,6 +17,7 @@ import abc
 import os
 import requests
 import requests.exceptions
+import simplejson.errors
 import yaml
 
 __all__ = [
@@ -64,7 +65,7 @@ class LoggingTestCase(SingleMasterSedDocumentCombineArchiveTestCase):
             msg = (
                 'The simulator did not export information about the status of its execution. '
                 'Simulators are encouraged to stream information about their execution status.\n\n'
-                'More information: https://biosimulators.org/conventions/status'
+                'More information: https://docs.biosimulations.org/concepts/conventions/simulation-run-logs/'
             )
             raise SkippedTestCaseException(msg)
 
@@ -85,15 +86,19 @@ class LoggingTestCase(SingleMasterSedDocumentCombineArchiveTestCase):
             except requests.exceptions.HTTPError:
                 msg = (
                     'The simulation log is invalid. Documentation about the log format is available at '
-                    'https://biosimulators.org/conventions and https://api.biosimulators.org.'
+                    'https://docs.biosimulations.org/concepts/conventions/simulation-run-logs/ and https://api.biosimulations.org.'
                 )
-                error = response.json()['error'][0]
 
-                pointer = error.get('source', {}).get('pointer', None)
-                if pointer:
-                    msg += '\n\nSource: ' + pointer
+                try:
+                    error = response.json()['error'][0]
 
-                msg += '\n\n' + error['detail']
+                    pointer = error.get('source', {}).get('pointer', None)
+                    if pointer:
+                        msg += '\n\nSource: ' + pointer
+
+                    msg += '\n\n' + error['detail']
+                except simplejson.errors.JSONDecodeError:
+                    msg += '\n\n{}: {}'.format(response.status_code, response.text)
 
                 raise InvalidOutputsException(msg)
 
